package com.supermap.topodataprocess;
/**
 * <p>
 * Title:Processing Topological Data
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Statement----------------------------
 * This is for SuperMap iMobile for Android Sample Code 
 * Copyright: SuperMap Software Co., Ltd.
 * ----------------------------------------------------------------
 * ----------------------------SuperMap iMobile
 * Demo---------------------------
 * 
 * 1. Introduction:
 *   	Demonstrate the functions of topology editing and topology capture.
 *   
 * 2. Demo Data:
 * 		Directory: "../SampleData/TopoDataprocessData/"
 *      Map: "TopoDataprocess.smwu", "TopoDataprocess.udb", "TopoDataprocess.udd"
 *      License: "../SuperMap/License/"
 *      
 * 3. Members:
 *    m_mapControl.setAction();						Method
 *    snapSetting.openDefault();					Method
 *    snapSetting.openAll();						Method
 *    snapClose.closeAll();							Method
 *    m_mapControl.setSnapSetting(snapSetting);		Method
 *    m_mapControl.undo();							Method
 *    m_mapControl.redo();							Method		
 *    TopoBuild.topoBuildRegion();					Method
 *
 * 4. Functions
 *   (1)Wipe, divide, merge, group, intersection, supplement donut holes, fill in donut holes
 *   (2)Default snap, snap all, constructing polygon from topology, rollback, redo
 *   (3)drawing point, line, region
 *   (4)Select object, translate object
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */

import com.supermap.analyst.TopoBuild;
import com.supermap.data.Dataset;
import com.supermap.data.DatasetVector;
import com.supermap.data.Environment;
import com.supermap.data.Workspace;
import com.supermap.data.WorkspaceConnectionInfo;
import com.supermap.data.WorkspaceType;
import com.supermap.mapping.Action;
import com.supermap.mapping.MapControl;
import com.supermap.mapping.MapView;
import com.supermap.mapping.SnapSetting;
import android.app.Activity;
import android.os.Bundle;
import android.view.View;



public class MainActivity extends Activity {
	
	private MapControl m_mapControl = null;
	private Workspace m_wokspace = null;
	private MapView m_mapView = null;
	
	final String sdcard = android.os.Environment.getExternalStorageDirectory().getAbsolutePath().toString();
	
	boolean m_bShowEditButtons = false;
	boolean m_bShowSnapButtons = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        	//Set path for license file
        	Environment.setLicensePath(sdcard + "/SuperMap/license/");
      		//Initialize Environment
      		Environment.initialization(this);
            //Close OpenGL mode
      		Environment.setOpenGLMode(false);
      		
      		setContentView(R.layout.activity_main);
              
      		 //Open the workspace
            m_wokspace = new Workspace();
            WorkspaceConnectionInfo info = new WorkspaceConnectionInfo();
            info.setServer(sdcard+"/SampleData/TopoDataprocessData/TopoDataprocess.smwu");
            info.setType(WorkspaceType.SMWU);
            m_wokspace.open(info);
                  
            //Map display controls are associated with workspace
            m_mapView = (MapView)findViewById(R.id.Map_view);
            m_mapControl =  m_mapView.getMapControl();
            m_mapControl.getMap().setWorkspace(m_wokspace);
            
            //Open the first map in workspace.
            String mapName = m_wokspace.getMaps().get(0);
            m_mapControl.getMap().open(mapName);
            
            //Refresh map        
            m_mapControl.getMap().refresh();
            
            //Set the buttons don't show
            ShowEditButtons(false);
            ShowSnapButtons(false);
    }
    
    //Zoom in button
    public void btnZoomIn_Click(View view){
    	
    	m_mapControl.getMap().zoom(2);
    	m_mapControl.getMap().refresh();
    }
    //Zoom out button
    public void btnZoomOut_Click(View view){
    	
    	m_mapControl.getMap().zoom(0.5);
    	m_mapControl.getMap().refresh();
    }
    //Full screen button
    public void btnFullScreen_Click(View view){
    	
    	m_mapControl.getMap().viewEntire();
    }
    
    //Topology Snap button
    public void btnSnap_Click(View view){
    	
    	ShowSnapButtons(!m_bShowSnapButtons);
    }
    //"Topology Edit button
    public void btnEdit_Click(View view){
    	
    	ShowEditButtons(!m_bShowEditButtons);
    }
    //Draw Point button
    public void btnDrawPoint_Click(View view){
    	
    	m_mapControl.setAction(Action.CREATEPOINT);
    	m_mapControl.getMap().getLayers().get("Point@TopoDataprocess").setEditable(true);
    }
  //Draw Line button
    public void btnDrawLine_Click(View view){
    	
    	m_mapControl.setAction(Action.CREATEPOLYLINE);
    	m_mapControl.getMap().getLayers().get("Line@TopoDataprocess").setEditable(true);
    }
    //Draw Region button
    public void btnDrawRegion_Click(View view){
    	
    	m_mapControl.setAction(Action.CREATEPOLYGON);
    	m_mapControl.getMap().getLayers().get("Region@TopoDataprocess").setEditable(true);
    }
    //Submit button
    public void btnCommit_Click(View view){
    	
    	m_mapControl.submit();
    	m_mapControl.setAction(Action.PAN);
    }
    //Select button
    public void btnSelect_Click(View view){
    	
    	m_mapControl.setAction(Action.SELECT);
    }
    //Clear button
    public void btnClear_Click(View view){
    	
    	m_mapControl.deleteCurrentGeometry();
    	m_mapControl.setAction(Action.SELECT);
    }
    //Translate button
    public void btnMove_Click(View view){
    	
    	m_mapControl.setAction(Action.MOVE_GEOMETRY);
    	m_mapControl.getMap().refresh();
    }
  
    //Topology Snap_ Default Snap
    public void btnSnapDefault_Click(View view){
    	
    	SnapSetting snapSetting = new SnapSetting();
		//Open the snapping mode
		snapSetting.openDefault();
		//Snap setting
		m_mapControl.setSnapSetting(snapSetting);
    }
    //Topology Snap_Snap all
    public void btnSnapAll_Click(View view){
    	
    	SnapSetting snapSetting = new SnapSetting();
		snapSetting.openAll();
		m_mapControl.setSnapSetting(snapSetting);
    }
    //Topology Snap_Construct Region from Topology
    public void btnSnapToRegion_Click(View view){
    	
    	//Get line dataset
    	Dataset datasetLine = m_mapControl.getMap().getLayers().get("Line@TopoDataprocess").getDataset();
    	DatasetVector datasetRegion = (DatasetVector)m_mapControl.getMap().getLayers().get("Region@TopoDataprocess").getDataset();
		//Line dataset generates region dateset from topology
		boolean bTopoBuild = TopoBuild.topoBuildRegion(datasetLine, datasetRegion);
		if(bTopoBuild == true){
			System.out.println("succeed!");
		}
		
		m_mapControl.getMap().refresh();
    }
    //Topology Snap_Close
    public void btnSnapClose_Click(View view){
    	
    	//Create a snap setting
		SnapSetting snapClose = new SnapSetting();
		//Open all modes
		snapClose.closeAll();
		//Snap setting
		m_mapControl.setSnapSetting(snapClose);
    }
    //Rollback
    public void btnSnapUndo_Click(View view){
    	
    	m_mapControl.undo();
    }
    //Redo
    public void btnSnapRedo_Click(View view){
    	
    	m_mapControl.redo();
    }
    
    //Erase Region button
    public void btnEditRegionDivide_Click(View view){
    	
    	m_mapControl.setAction(Action.ERASE_REGION);
    }
    //Divide Region button
    public void btnEditRegionLineDivide_Click(View view){
    	
    	m_mapControl.setAction(Action.SPLIT_BY_LINE);
    }
    //Merge Region button
    public void btnEditRegionUnion_Click(View view){
    	
    	m_mapControl.getMap().getLayers().get("Region@TopoDataprocess").setEditable(true);
    	m_mapControl.setAction(Action.UNION_REGION);
    }
    //Region Group button 
    public void btnEditRegionCompose_Click(View view){
    	m_mapControl.getMap().getLayers().get("Region@TopoDataprocess").setEditable(true);
    	m_mapControl.setAction(Action.COMPOSE_REGION);
    }
    //Region Intersect
    public void btnEditRegionIntersect_Click(View view){
    	m_mapControl.getMap().getLayers().get("Region@TopoDataprocess").setEditable(true);
    	m_mapControl.setAction(Action.INTERSECT_REGION);
    }
    //Supplement Donut Holes button
    public void btnEditRegionIslandDivide_Click(View view){
    	
    	m_mapControl.setAction(Action.PATCH_HOLLOW_REGION);
    }
    //Fill in Donut Holes button
    public void btnEditRegionIslandFill_Click(View view){
    	
    	m_mapControl.setAction(Action.FILL_HOLLOW_REGION);
    }
    //Translate button
    public void btnEditMoveGeometry_Click(View view){
    	
    	m_mapControl.setAction(Action.MOVE_GEOMETRY);
    }
    
    public void ShowEditButtons(boolean bShow){
    	
    	if(bShow){
    		findViewById(R.id.btnEditRegionDivide).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnEditRegionLineDivide).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnEditRegionUnion).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnEditRegionCompose).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnEditRegionIntersect).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnEditRegionIslandDivide).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnEditRegionIslandFill).setVisibility(View.VISIBLE);
    		
    		if(m_bShowSnapButtons){
    			ShowSnapButtons(false);
    		}
    	}
    	else{
    		findViewById(R.id.btnEditRegionDivide).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnEditRegionLineDivide).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnEditRegionUnion).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnEditRegionCompose).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnEditRegionIntersect).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnEditRegionIslandDivide).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnEditRegionIslandFill).setVisibility(View.INVISIBLE);
    	}
    	
    	m_bShowEditButtons = bShow;
    }
    
    public void ShowSnapButtons(boolean bShow){
    	
    	if(bShow){
    		findViewById(R.id.btnSnapDefault).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnSnapAll).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnSnapToRegion).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnSnapClose).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnSnapUndo).setVisibility(View.VISIBLE);
    		findViewById(R.id.btnSnapRedo).setVisibility(View.VISIBLE);
    		
    		if(m_bShowEditButtons){
    			ShowEditButtons(false);
    		}
    	}
    	else{
    		findViewById(R.id.btnSnapDefault).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnSnapAll).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnSnapToRegion).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnSnapClose).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnSnapUndo).setVisibility(View.INVISIBLE);
    		findViewById(R.id.btnSnapRedo).setVisibility(View.INVISIBLE);
    	}
    	
    	m_bShowSnapButtons = bShow;
    }

}
